==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/fr.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Vous ne pouvez pas supprimer votre propre autorisation de lecture.",
    "Team folders" : "Dossiers d'équipe",
    "Admin configured folders shared with everyone in a team" : "Dossiers configurés par un administrateur et partagés avec tous les membres d'une équipe",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Dossiers configurés par l'administrateur et partagés avec tous les membres d'une équipe.\n\nLes dossiers peuvent être configurés à partir de *Dossiers d'équipe* dans les paramètres d'administration.\n\nAprès la création d'un dossier, l'administrateur peut donner accès au dossier à une ou plusieurs équipes, contrôler leurs permissions d'écriture/partage et assigner un quota pour le dossier.\nDepuis Hub 10/Nextcloud 31, l'administrateur doit faire partie de l'équipe pour pouvoir lui attribuer un dossier d'équipe",
    "Unset" : "Désactiver",
    "Denied (Inherited permission)" : "Interdit (permission héritée)",
    "Allowed (Inherited permission)" : "Autorisé (permission héritée)",
    "Denied" : "Interdit",
    "Allowed" : "Autorisé",
    "Access denied" : "Accès refusé",
    "Access allowed" : "Accès autorisé",
    "Inherit permission" : "Hériter de l'autorisation",
    "Deny" : "Interdire",
    "Allow" : "Autoriser",
    "Group" : "Groupe",
    "Team" : "Équipe",
    "Team folder" : "Dossier d'équipe",
    "Read" : "Lire",
    "Write" : "Écrire",
    "Create" : "Créer",
    "Delete" : "Supprimer",
    "Share" : "Partager",
    "You" : "Vous",
    "Remove access rule" : "Retirer la règle d'autorisation avancée",
    "Add advanced permission rule" : "Ajouter une règle d'autorisation avancée",
    "Select a user or group" : "Sélectionnez un utilisateur ou un groupe",
    "Open Team folder" : "Ouvrir le dossier d'équipe",
    "Permission denied. User does not have sufficient permissions." : "Permission refusée. L'utilisateur ne dispose pas des autorisations suffisantes.",
    "Unexpected status from server" : "Statut inattendu du serveur",
    "List of Team folders." : "Liste des dossiers d'équipe",
    "No Team folders yet" : "Pas encore de dossiers d'équipe",
    "Team folders will show up here" : "Les dossiers d'équipe apparaîtront ici",
    "Add group" : "Ajouter un groupe",
    "Default" : "Défaut",
    "Unlimited" : "Illimité",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Voulez-vous vraiment supprimer « {folderName} » et tout son contenu ? Cette opération ne pourra pas être annulée.",
    "Delete \"{folderName}\"?" : "Supprimer \"{folderName}\" ?",
    "Team folder admin delegation" : "Délégation de l'administration des dossiers d'équipe",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud vous permet de déléguer l'administration des dossiers d'équipe à des utilisateurs non-administrateurs.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Indiquez ci-dessous les groupes qui seront autorisés à gérer les dossiers d'équipe et à utiliser son API/REST.",
    "They will have access to all Team folders." : "Ils auront accès à tous les dossiers d'équipe.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Indiquez ci-dessous les groupes qui seront autorisés à gérer les dossiers d'équipe et à utiliser uniquement son API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Ils n'auront accès qu'aux dossiers d'équipe pour lesquels ils disposent d'autorisations avancées.",
    "Group or team" : "Groupe ou équipe",
    "Sort by number of groups or teams that have access to this folder" : "Trier par nombre de groupes ou d'équipes ayant accès à ce dossier",
    "Sort by number of groups that have access to this folder" : "Trier par nombre de groupes ayant accès à ce dossier",
    "Folder name" : "Nom du dossier",
    "Quota" : "Quota",
    "Advanced Permissions" : "Autorisations avancées",
    "Pagination of team folders" : "Pagination des dossiers d'équipe",
    "Previous" : "Précédent",
    "Next" : "Suivant",
    "User" : "Utilisateur",
    "Unknown" : "Inconnu",
    "Users/groups that can manage" : "Utilisateurs/groupes qui peuvent gérer",
    "None" : "Aucun",
    "No other groups or teams available" : "Pas d'autres groupes ou équipes disponibles",
    "No other groups available" : "Pas d'autres groupes disponibles",
    "{displayName} (team)" : "{displayName} (équipe)",
    "Add group or team" : "Ajouter un groupe ou une équipe",
    "{size} used" : "{size} utilisés",
    "Other …" : "Autres...",
    "You can not remove your own read permission." : "Vous ne pouvez pas retirer votre propre autorisation de lecture.",
    "Group folders" : "Dossiers de groupe",
    "Admin configured folders shared with everyone in a group" : "L'administrateur a configuré des dossiers partagés avec tous les membres d'un groupe",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Dossiers configurés par l'administrateur et partagés avec tous les membres d'un groupe.\n\nLes dossiers peuvent être configurés à partir de *Group folders* dans les paramètres d'administration.\n\nAprès la création d'un dossier, l'administrateur peut donner accès au dossier à un ou plusieurs groupes, contrôler leurs droits d'écriture et de partage et attribuer un quota pour le dossier.",
    "Group folder" : "Dossier de groupes",
    "Open group folder" : "Ouvrir le dossier de groupes",
    "List of group folders." : "Liste des dossiers de groupe",
    "No group folders yet" : "Pas encore de dossiers de groupe",
    "Group folders will show up here" : "Les dossiers de groupe apparaîtront ici",
    "Group folder admin delegation" : "Délégation de l'administration des dossiers de groupe",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud vous permet de déléguer l'administration des dossiers de groupe à des utilisateurs non-administrateurs.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Indiquez ci-dessous les groupes qui seront autorisés à gérer les dossiers de groupe et à utiliser son API/REST.",
    "They will have access to all group folders." : "Ils auront accès à tous les dossiers de groupe.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Indiquez ci-dessous les groupes qui seront autorisés à gérer les dossiers de groupe et à utiliser uniquement son API/REST.",
    "They will only have access to group folders for which they have advanced permissions." : "Ils n'auront accès qu'aux dossiers de groupe pour lesquels ils disposent de permissions avancées.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Dossiers configurés par un administrateur et partagés avec tous les membres d'une équipe.\n\nLes dossiers peuvent être configurés à partir de *Dossiers d'équipe* dans les paramètres d'administration.\n\nAprès la création d'un dossier, l'administrateur peut donner accès au dossier à une ou plusieurs équipes, contrôler leurs droits d'écriture et de partage et attribuer un quota pour le dossier."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/fr.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Vous ne pouvez pas supprimer votre propre autorisation de lecture.",
    "Team folders" : "Dossiers d'équipe",
    "Unset" : "Désactiver",
    "Denied (Inherited permission)" : "Interdit (permission héritée)",
    "Allowed (Inherited permission)" : "Autorisé (permission héritée)",
    "Denied" : "Interdit",
    "Allowed" : "Autorisé",
    "Access denied" : "Accès refusé",
    "Access allowed" : "Accès autorisé",
    "Inherit permission" : "Hériter de l'autorisation",
    "Deny" : "Interdire",
    "Allow" : "Autoriser",
    "Group" : "Groupe",
    "Team" : "Équipe",
    "Team folder" : "Dossier d'équipe",
    "Read" : "Lire",
    "Write" : "Écrire",
    "Create" : "Créer",
    "Delete" : "Supprimer",
    "Share" : "Partager",
    "You" : "Vous",
    "Remove access rule" : "Retirer la règle d'autorisation avancée",
    "Add advanced permission rule" : "Ajouter une règle d'autorisation avancée",
    "Select a user or group" : "Sélectionnez un utilisateur ou un groupe",
    "Open Team folder" : "Ouvrir le dossier d'équipe",
    "Permission denied. User does not have sufficient permissions." : "Permission refusée. L'utilisateur ne dispose pas des autorisations suffisantes.",
    "Unexpected status from server" : "Statut inattendu du serveur",
    "List of Team folders." : "Liste des dossiers d'équipe",
    "No Team folders yet" : "Pas encore de dossiers d'équipe",
    "Team folders will show up here" : "Les dossiers d'équipe apparaîtront ici",
    "Add group" : "Ajouter un groupe",
    "Default" : "Défaut",
    "Unlimited" : "Illimité",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Voulez-vous vraiment supprimer « {folderName} » et tout son contenu ? Cette opération ne pourra pas être annulée.",
    "Delete \"{folderName}\"?" : "Supprimer \"{folderName}\" ?",
    "Team folder admin delegation" : "Délégation de l'administration des dossiers d'équipe",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud vous permet de déléguer l'administration des dossiers d'équipe à des utilisateurs non-administrateurs.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Indiquez ci-dessous les groupes qui seront autorisés à gérer les dossiers d'équipe et à utiliser son API/REST.",
    "They will have access to all Team folders." : "Ils auront accès à tous les dossiers d'équipe.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Indiquez ci-dessous les groupes qui seront autorisés à gérer les dossiers d'équipe et à utiliser uniquement son API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Ils n'auront accès qu'aux dossiers d'équipe pour lesquels ils disposent d'autorisations avancées.",
    "Group or team" : "Groupe ou équipe",
    "Sort by number of groups or teams that have access to this folder" : "Trier par nombre de groupes ou d'équipes ayant accès à ce dossier",
    "Sort by number of groups that have access to this folder" : "Trier par nombre de groupes ayant accès à ce dossier",
    "Folder name" : "Nom du dossier",
    "Quota" : "Quota",
    "Advanced Permissions" : "Autorisations avancées",
    "Pagination of team folders" : "Pagination des dossiers d'équipe",
    "Previous" : "Précédent",
    "Next" : "Suivant",
    "User" : "Utilisateur",
    "Unknown" : "Inconnu",
    "Users/groups that can manage" : "Utilisateurs/groupes qui peuvent gérer",
    "None" : "Aucun",
    "No other groups or teams available" : "Pas d'autres groupes ou équipes disponibles",
    "No other groups available" : "Pas d'autres groupes disponibles",
    "{displayName} (team)" : "{displayName} (équipe)",
    "Add group or team" : "Ajouter un groupe ou une équipe",
    "{size} used" : "{size} utilisés",
    "Other …" : "Autres...",
    "You can not remove your own read permission." : "Vous ne pouvez pas retirer votre propre autorisation de lecture.",
    "Group folders" : "Dossiers de groupe",
    "Admin configured folders shared with everyone in a group" : "L'administrateur a configuré des dossiers partagés avec tous les membres d'un groupe",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Dossiers configurés par l'administrateur et partagés avec tous les membres d'un groupe.\n\nLes dossiers peuvent être configurés à partir de *Group folders* dans les paramètres d'administration.\n\nAprès la création d'un dossier, l'administrateur peut donner accès au dossier à un ou plusieurs groupes, contrôler leurs droits d'écriture et de partage et attribuer un quota pour le dossier.",
    "Group folder" : "Dossier de groupes",
    "Open group folder" : "Ouvrir le dossier de groupes",
    "List of group folders." : "Liste des dossiers de groupe",
    "No group folders yet" : "Pas encore de dossiers de groupe",
    "Group folders will show up here" : "Les dossiers de groupe apparaîtront ici",
    "Group folder admin delegation" : "Délégation de l'administration des dossiers de groupe",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud vous permet de déléguer l'administration des dossiers de groupe à des utilisateurs non-administrateurs.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Indiquez ci-dessous les groupes qui seront autorisés à gérer les dossiers de groupe et à utiliser son API/REST.",
    "They will have access to all group folders." : "Ils auront accès à tous les dossiers de groupe.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Indiquez ci-dessous les groupes qui seront autorisés à gérer les dossiers de groupe et à utiliser uniquement son API/REST.",
    "They will only have access to group folders for which they have advanced permissions." : "Ils n'auront accès qu'aux dossiers de groupe pour lesquels ils disposent de permissions avancées.",
    "Admin configured folders shared with everyone in a team" : "Dossiers configurés par un administrateur et partagés avec tous les membres d'une équipe",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Dossiers configurés par un administrateur et partagés avec tous les membres d'une équipe.\n\nLes dossiers peuvent être configurés à partir de *Dossiers d'équipe* dans les paramètres d'administration.\n\nAprès la création d'un dossier, l'administrateur peut donner accès au dossier à une ou plusieurs équipes, contrôler leurs droits d'écriture et de partage et attribuer un quota pour le dossier.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Dossiers configurés par l'administrateur et partagés avec tous les membres d'une équipe.\n\nLes dossiers peuvent être configurés à partir de *Dossiers d'équipe* dans les paramètres d'administration.\n\nAprès la création d'un dossier, l'administrateur peut donner accès au dossier à une ou plusieurs équipes, contrôler leurs permissions d'écriture/partage et assigner un quota pour le dossier.\nDepuis Hub 10/Nextcloud 31, l'administrateur doit faire partie de l'équipe pour pouvoir lui attribuer un dossier d'équipe"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
